import 'package:flutter/material.dart';

import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:intl/date_symbol_data_local.dart';
import 'package:intl/intl.dart' show DateFormat;

import '../../widgets/panel.dart';

class CalendarExemple extends StatefulWidget {
  CalendarExemple({Key? key}) : super(key: key);

  @override
  State<CalendarExemple> createState() => _CalendarExempleState();
}

class _CalendarExempleState extends State<CalendarExemple> {
  DateTime _currentDateVacation = DateTime.now();
  DateTime _currentDateBirthday = DateTime.now();

  @override
  void initState() {
    /// Add more events to _markedDateMap EventList
    initializeDateFormatting();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final TextEditingController editingControllerBirthday =
        TextEditingController();
    final TextEditingController editingControllerVacation =
        TextEditingController();
    const String locate = 'en';
    late DateFormat localeDate;
    localeDate = DateFormat('d/MM/yyyy', locate);

    return Scaffold(
      body: Center(
          child: SingleChildScrollView(
        child: Column(
          children: [
            Panel(
              title: 'Example Calendar Birthday',
              child: Column(
                children: [
                  SeniorTextField(
                    controller: editingControllerBirthday,
                    label: localeDate.format(_currentDateBirthday),
                    maxLines: 1,
                    leftIcon: FontAwesomeIcons.rocket,
                  ),
                  SeniorButton(
                    label: 'Example Calendar Birthday',
                    onPressed: () {
                      SeniorCalendar(
                        daysHaveCircularBorder: true,
                        inactiveYesterdays: true,
                        topTextCalendar: 'Select your birthday',
                        selectedDateTime: _currentDateBirthday,
                        minSelectedDate: DateTime(DateTime.now().year, 1, 1),
                        maxSelectedDate: DateTime(DateTime.now().year, 12, 31),
                        highlightToday: true,
                        inactiveWeekendAfterToday: false,
                        inactiveWeekendBeforeToday: false,
                        locale: locate,
                        onDayPressed: (date) {
                          setState(() => _currentDateBirthday = date);
                          Navigator.pop(context);
                        },
                      ).pickCalendar(context);
                    },
                  ),
                ],
              ),
            ),
            const SizedBox(height: 20),
            Panel(
              title: 'Example Calendar Vacation',
              child: Column(
                children: [
                  SeniorTextField(
                    controller: editingControllerVacation,
                    label: localeDate.format(_currentDateVacation),
                    maxLines: 1,
                    leftIcon: FontAwesomeIcons.calendarDays,
                  ),
                  SeniorButton(
                    label: 'Example Calendar Vacation',
                    onPressed: () {
                      SeniorCalendar(
                        daysHaveCircularBorder: true,
                        highlightToday: true,
                        inactiveYesterdays: true,
                        inactiveWeekendAfterToday: false,
                        disableYesterdayPressed: true,
                        topTextCalendar: 'I would like to start my vacation in',
                        bottomTextCalendar:
                            'Enter the start date of your vacation',
                        selectedDateTime: _currentDateVacation,
                        minSelectedDate: DateTime.now(),
                        maxSelectedDate: DateTime(2022, 12, 31),
                        locale: locate,
                        onDayPressed: (date) {
                          setState(() => _currentDateVacation = date);
                          Navigator.pop(context);
                        },
                      ).pickCalendar(context);
                    },
                  ),
                ],
              ),
            ),
          ],
        ),
      )),
    );
  }
}
