import 'package:flutter/material.dart';

import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../components/senior_calendar/senior_calendar_style.dart';
import '../../senior_themes.dart';

class SeniorCalendarHeader extends StatelessWidget {
  /// Passing in values for [leftButtonIcon] or [rightButtonIcon] will override [headerIconColor]
  SeniorCalendarHeader({
    required this.headerTitle,
    this.headerMargin,
    required this.showHeader,
    this.showHeaderButtons = true,
    required this.onLeftButtonPressed,
    required this.onRightButtonPressed,
    this.onHeaderTitlePressed,
    this.leftButtonActive,
    this.rightButtonActive,
    this.style,
  }) : isTitleTouchable = onHeaderTitlePressed != null;

  final SeniorCalendarStyle? style;
  final bool? leftButtonActive;
  final bool? rightButtonActive;
  final String headerTitle;
  final EdgeInsetsGeometry? headerMargin;
  final bool showHeader;
  final bool showHeaderButtons;
  final VoidCallback onLeftButtonPressed;
  final VoidCallback onRightButtonPressed;
  final bool isTitleTouchable;
  final VoidCallback? onHeaderTitlePressed;

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme =
        SeniorThemeProvider.getDefaultTheme(context);

    TextStyle _headerTitleStyle() {
      return SeniorTypography.text(
        color: style?.headerTextColor ??
            theme?.calendarTheme?.style?.headerTextColor ??
            defaultTheme.calendarTheme?.style?.headerTextColor ??
            SeniorColors.neutralColor900,
      );
    }

    Widget _headerTouchable() {
      return TextButton(
        onPressed: onHeaderTitlePressed,
        child: Text(
          headerTitle,
          semanticsLabel: headerTitle,
          style: _headerTitleStyle(),
        ),
      );
    }

    return showHeader
        ? Container(
            padding:
                const EdgeInsets.symmetric(horizontal: SeniorSpacing.small),
            margin: headerMargin,
            child: DefaultTextStyle(
              style: _headerTitleStyle(),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  showHeaderButtons
                      ? _headerButton(
                          onLeftButtonPressed,
                          leftButtonActive!,
                          FontAwesomeIcons.angleLeft,
                        )
                      : const SizedBox.shrink(),
                  isTitleTouchable
                      ? _headerTouchable()
                      : Text(
                          headerTitle,
                          style: _headerTitleStyle(),
                        ),
                  showHeaderButtons
                      ? _headerButton(
                          onRightButtonPressed,
                          rightButtonActive!,
                          FontAwesomeIcons.angleRight,
                        )
                      : const SizedBox.shrink(),
                ],
              ),
            ),
          )
        : Container();
  }

  Widget _headerButton(
    Function() onTap,
    bool headButtonActive,
    IconData icon,
  ) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        height: 28.0,
        width: 28.0,
        decoration: BoxDecoration(
          border: Border.all(
            color: SeniorColors.secondaryColor500,
            width: 1.0,
          ),
          borderRadius: BorderRadius.circular(SeniorSpacing.xsmall),
        ),
        child: Icon(
          icon,
          color: headButtonActive
              ? SeniorColors.neutralColor900
              : SeniorColors.secondaryColor300,
          size: SeniorSpacing.small,
        ),
      ),
    );
  }
}
