import 'package:flutter/material.dart';

import 'package:intl/intl.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../themes/senior_theme.dart';
import '../../themes/senior_theme_provider.dart';
import '../../components/senior_calendar/senior_calendar.dart';

class SeniorWeekdayRow extends StatelessWidget {
  SeniorWeekdayRow(
    this.firstDayOfWeek,
    this.customWeekdayBuilder, {
    required this.showWeekdays,
    required this.weekdayFormat,
    required this.weekdayMargin,
    required this.weekdayPadding,
    required this.localeDate,
    this.style,
  });

  final WeekdayBuilder? customWeekdayBuilder;
  final bool showWeekdays;
  final WeekdayFormat weekdayFormat;
  final EdgeInsets weekdayMargin;
  final EdgeInsets weekdayPadding;
  final DateFormat localeDate;
  final int firstDayOfWeek;
  final SeniorCalendarStyle? style;

  Widget _weekdayContainer({
    required int weekday,
    required String weekDayName,
    required SeniorTheme? theme,
    required SeniorTheme defaultTheme,
  }) {
    final customWeekdayBuilder = this.customWeekdayBuilder;

    Color _getWeekdayBackgroundColor() {
      return style?.weekdayBackgroundColor ??
          theme?.calendarTheme?.style?.weekdayBackgroundColor ??
          defaultTheme.calendarTheme?.style?.weekdayBackgroundColor ??
          Colors.transparent;
    }

    Color _getWeekdayTextColor() {
      return style?.weekdayTextColor ??
          theme?.calendarTheme?.style?.weekdayTextColor ??
          defaultTheme.calendarTheme?.style?.weekdayTextColor ??
          Colors.black;
    }

    return customWeekdayBuilder != null
        ? customWeekdayBuilder(weekday, weekDayName)
        : Expanded(
            child: Container(
            decoration: BoxDecoration(
              border: Border.all(color: _getWeekdayBackgroundColor()),
              color: _getWeekdayBackgroundColor(),
            ),
            //padding: weekdayPadding,
            child: Center(
              child: Text(
                capitalize(weekDayName),
                semanticsLabel: weekDayName,
                style: SeniorTypography.text(color: _getWeekdayTextColor()),
              ),
            ),
          ));
  }

  String capitalize(String string) {
    return '${string[0].toUpperCase()}${string.substring(1).toLowerCase()}';
  }

  List<Widget> _renderWeekDays({
    required SeniorTheme? theme,
    required SeniorTheme defaultTheme,
  }) {
    final List<Widget> list = [];

    /// because of number of days in a week is 7, so it would be easier to count it til 7.
    // ignore: avoid_multiple_declarations_per_line
    for (var i = firstDayOfWeek, count = 0;
        count < 7;
        i = (i + 1) % 7, count++) {
      String weekDay;

      switch (weekdayFormat) {
        case WeekdayFormat.weekdays:
          weekDay = localeDate.dateSymbols.WEEKDAYS[i];
          break;
        case WeekdayFormat.standalone:
          weekDay = localeDate.dateSymbols.STANDALONEWEEKDAYS[i];
          break;
        case WeekdayFormat.short:
          weekDay = localeDate.dateSymbols.SHORTWEEKDAYS[i];
          break;
        case WeekdayFormat.standaloneShort:
          weekDay = localeDate.dateSymbols.STANDALONESHORTWEEKDAYS[i];
          break;
        case WeekdayFormat.narrow:
          weekDay = localeDate.dateSymbols.NARROWWEEKDAYS[i];
          break;
        case WeekdayFormat.standaloneNarrow:
          weekDay = localeDate.dateSymbols.STANDALONENARROWWEEKDAYS[i];
          break;
        default:
          weekDay = localeDate.dateSymbols.STANDALONEWEEKDAYS[i];
          break;
      }
      list.add(
        _weekdayContainer(
          weekday: count,
          weekDayName: weekDay,
          theme: theme,
          defaultTheme: defaultTheme,
        ),
      );
    }

    return list;
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme =
        SeniorThemeProvider.getDefaultTheme(context);

    return showWeekdays
        ? Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: _renderWeekDays(
              defaultTheme: defaultTheme,
              theme: theme,
            ),
          )
        : Container();
  }
}
