// ignore_for_file: public_member_api_docs, sort_constructors_first
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../components/senior_stepper/senior_stepper.dart';
import '../../senior_themes.dart';

class SeniorStepper extends StatelessWidget {
  /// Creates a Stepper component according to SDS.
  ///
  /// The [steps] and [current] parameters are required.
  const SeniorStepper({
    Key? key,
    required this.steps,
    required this.current,
    this.style,
  }) : super(key: key);

  //Defines the number of steps the component will have
  final int steps;
  //Indicates the current position on the stepper
  final int current;

  /// Allows you to configure:
  /// [SeniorStepperStyle.enabledColor] the color to use when this Stepper is selected.
  /// [SeniorStepperStyle.disabledColor] the color to use when this Stepper is not selected.
  final SeniorStepperStyle? style;

  Widget _buildStepper(SeniorTheme? theme, SeniorTheme defaultTheme) {
    final Color _enabledColor = style?.enabledColor ??
        theme?.stepperTheme?.style?.enabledColor ??
        defaultTheme.stepperTheme?.style?.enabledColor ??
        SeniorColors.primaryColor;

    final Color _disabledColor = style?.disabledColor ??
        theme?.stepperTheme?.style?.disabledColor ??
        defaultTheme.stepperTheme?.style?.disabledColor ??
        SeniorColors.secondaryColor;

    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        for (int i = 1; i <= steps; i++)
          Expanded(
            child: Padding(
              padding: EdgeInsets.only(
                right: i == steps ? 0 : SeniorSpacing.xxsmall,
              ),
              child: AnimatedContainer(
                height: SeniorSpacing.xxsmall,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(3.0),
                  color: (i == current)
                      ? _enabledColor
                      : (i < current)
                          ? _enabledColor.withOpacity(0.5)
                          : _disabledColor,
                ),
                duration: const Duration(
                  milliseconds: 200,
                ),
              ),
            ),
          ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme =
        SeniorThemeProvider.getDefaultTheme(context);

    return _buildStepper(theme, defaultTheme);
  }
}
