import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../components/senior_action_button/senior_action_button.dart';
import '../../components/senior_balance/senior_balance.dart';
import '../../components/senior_bottom_navigation_bar/senior_bottom_navigation_bar.dart';
import '../../components/senior_bottom_sheet/senior_bottom_sheet.dart';
import '../../components/senior_button/senior_button.dart';
import '../../components/senior_calendar/senior_calendar.dart';
import '../../components/senior_card/senior_card.dart';
import '../../components/senior_checkbox/senior_checkbox.dart';
import '../../components/senior_contact_book_item/senior_contact_book_item.dart';
import '../../components/senior_drawer/senior_drawer.dart';
import '../../components/senior_dropdown_button/senior_dropdown_button.dart';
import '../../components/senior_expansion_panel_list/senior_expansion_panel_list.dart';
import '../../components/senior_icon_button/senior_icon_button.dart';
import '../../components/senior_info_card/senior_info_card.dart';
import '../../components/senior_list/senior_list.dart';
import '../../components/senior_loading/senior_loading.dart';
import '../../components/senior_menu_list_item/senior_menu_list_item.dart';
import '../../components/senior_message_card/senior_message_card.dart';
import '../../components/senior_modal/senior_modal.dart';
import '../../components/senior_notification_list/senior_notification_list.dart';
import '../../components/senior_profile_picture/senior_profile_picture.dart';
import '../../components/senior_progress_bar/senior_progress_bar.dart';
import '../../components/senior_quotes/senior_quotes.dart';
import '../../components/senior_radio_button/senior_radio_button.dart';
import '../../components/senior_rating/senior_rating.dart';
import '../../components/senior_signature/senior_signature.dart';
import '../../components/senior_snackbar/senior_snackbar.dart';
import '../../components/senior_square_buttons_menu/senior_square_buttons_menu.dart';
import '../../components/senior_switch/senior_switch.dart';
import '../../components/senior_tab_bar/senior_tab_bar.dart';
import '../../components/senior_text_field/senior_text_field.dart';
import '../../components/senior_timeline/senior_timeline.dart';
import '../senior_theme.dart';

final SeniorTheme seniorLightTheme = SeniorTheme(
  // Action button
  actionButtonTheme: const SeniorActionButtonThemeData(
    style: SeniorActionButtonStyle(
      color: Colors.transparent,
      iconColor: SeniorColors.secondaryColor900,
    ),
  ),
  pressActionButtonTheme: const SeniorActionButtonThemeData(
    style: const SeniorActionButtonStyle(
      color: SeniorColors.primaryColor,
      iconColor: SeniorColors.pureWhite,
    ),
  ),

  // Balance
  balanceTheme: const SeniorBalanceThemeData(
    style: SeniorBalanceStyle(
      textColor: SeniorColors.neutralColor600,
      selectedControllerColor: SeniorColors.neutralColor500,
      unselectedControllerColor: SeniorColors.neutralColor200,
    ),
  ),

  // Bottom sheet
  bottomSheetTheme: const SeniorBottomSheetThemeData(
    style: SeniorBottomSheetStyle(
      backgroundColor: SeniorColors.pureWhite,
      closeButtonColor: SeniorColors.primaryColor300,
      titleColor: SeniorColors.neutralColor900,
    ),
  ),

  // Bottom navigation bar
  bottomNavigationBarTheme: SeniorBottomNavigationBarThemeData(
    style: const SeniorBottomNavigationBarStyle(
      color: SeniorColors.neutralColor100,
      selectedItemColor: SeniorColors.primaryColor,
      unselectedItemColor: SeniorColors.neutralColor500,
      badgeColor: SeniorColors.primaryColor,
      badgeItemColor: SeniorColors.pureWhite,
    ),
  ),

  // Buttons
  primaryButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: SeniorColors.primaryColor,
      disabledColor: SeniorColors.primaryColor100,
      fontColor: SeniorColors.pureWhite,
      disabledFontColor: SeniorColors.primaryColor300,
      waveColor: SeniorColors.primaryColor100,
    ),
  ),
  secondaryButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: SeniorColors.secondaryColor,
      disabledColor: SeniorColors.secondaryColor100,
      fontColor: SeniorColors.pureWhite,
      disabledFontColor: SeniorColors.secondaryColor400,
      waveColor: SeniorColors.secondaryColor100,
    ),
  ),
  ghostButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: Colors.transparent,
      disabledFontColor: SeniorColors.primaryColor100,
      fontColor: SeniorColors.primaryColor,
      disabledColor: Colors.transparent,
      waveColor: SeniorColors.neutralColor400,
    ),
  ),
  dangerButtonTheme: SeniorButtonThemeData(
    style: SeniorButtonStyle(
      color: SeniorColors.manchesterColorRed,
      disabledColor: SeniorColors.manchesterColorRed300,
      fontColor: SeniorColors.pureWhite,
      disabledFontColor: SeniorColors.pureWhite,
      waveColor: SeniorColors.manchesterColorRed100,
    ),
  ),

  // Card
  cardTheme: const SeniorCardThemeData(
    style: SeniorCardStyle(
      backgroundColor: SeniorColors.neutralColor200,
      disabledBackgroundColor: SeniorColors.neutralColor200,
      backgroundColorIfElevated: SeniorColors.pureWhite,
      iconColor: SeniorColors.neutralColor800,
      quotesColor: SeniorColors.neutralColor600,
    ),
  ),

  // Checkbox
  checkboxTheme: const SeniorCheckboxThemeData(
    style: SeniorCheckboxStyle(
      activeColor: Colors.transparent,
    ),
  ),

  // Contact book item
  contactBookItemTheme: const SeniorContactBookItemThemeData(
    style: SeniorContactBookItemStyle(
      itemsColor: SeniorColors.neutralColor500,
      titleColor: SeniorColors.neutralColor800,
    ),
  ),

  // Drawer
  drawerTheme: const SeniorDrawerThemeData(
    style: SeniorDrawerStyle(
      backgroundColor: SeniorColors.pureWhite,
      backIconColor: SeniorColors.pureBlack,
      boldItemColor: SeniorColors.neutralColor700,
      emphasisItemColor: SeniorColors.primaryColor,
      footerTextColor: SeniorColors.neutralColor500,
      lineColor: SeniorColors.secondaryColor200,
      neutralItemColor: SeniorColors.neutralColor700,
      profileSubtitleColor: SeniorColors.neutralColor600,
      profileTitleColor: SeniorColors.neutralColor900,
    ),
  ),

  // Dropdown button
  dropdownButtonTheme: const SeniorDropdownButtonThemeData(
    style: SeniorDropdownButtonStyle(
      buttonColor: SeniorColors.neutralColor100,
      disabledButtonColor: SeniorColors.pureWhite,
      disabledHelperColor: SeniorColors.neutralColor400,
      disabledDropIconColor: SeniorColors.neutralColor400,
      disabledIconColor: SeniorColors.neutralColor400,
      disabledLabelColor: SeniorColors.neutralColor400,
      disabledSelectedItemTextColor: SeniorColors.neutralColor400,
      disabledUnderlineColor: SeniorColors.neutralColor400,
      dropIconColor: SeniorColors.neutralColor900,
      errorColor: SeniorColors.manchesterColorRed,
      iconColor: SeniorColors.secondaryColor900,
      itemListTextColor: SeniorColors.neutralColor800,
      labelColorEmpty: SeniorColors.secondaryColor900,
      labelColorFilled: SeniorColors.primaryColor,
      helperColor: SeniorColors.neutralColor700,
      popupMenuColor: SeniorColors.neutralColor100,
      selectedItemTextColor: SeniorColors.neutralColor600,
      underlineColor: SeniorColors.secondaryColor500,
    ),
  ),

  // Expansion panel list
  expansionPanelListTheme: const SeniorExpansionPanelListThemeData(
    style: SeniorExpansionPanelListStyle(
      backgroundColor: SeniorColors.neutralColor100,
    ),
  ),

  // Icon buttons
  primaryIconButtonTheme: SeniorIconButtonThemeData(
    style: SeniorIconButtonStyle(
      borderColor: Colors.transparent,
      buttonColor: SeniorColors.primaryColor,
      disabledBorderColor: Colors.transparent,
      disabledButtonColor: SeniorColors.primaryColor100,
      disabledIconColor: SeniorColors.primaryColor300,
      iconColor: SeniorColors.pureWhite,
      outlinedColor: SeniorColors.primaryColor200,
    ),
  ),
  secondaryIconButtonTheme: SeniorIconButtonThemeData(
    style: SeniorIconButtonStyle(
      borderColor: Colors.transparent,
      buttonColor: SeniorColors.secondaryColor,
      disabledBorderColor: Colors.transparent,
      disabledButtonColor: SeniorColors.secondaryColor100,
      disabledIconColor: SeniorColors.secondaryColor400,
      iconColor: SeniorColors.pureWhite,
      outlinedColor: SeniorColors.secondaryColor300,
    ),
  ),
  ghostIconButtonTheme: SeniorIconButtonThemeData(
    style: SeniorIconButtonStyle(
      borderColor: SeniorColors.secondaryColor200,
      buttonColor: SeniorColors.pureWhite,
      disabledBorderColor: SeniorColors.secondaryColor200,
      disabledButtonColor: SeniorColors.pureWhite,
      disabledIconColor: SeniorColors.primaryColor100,
      iconColor: SeniorColors.primaryColor,
      outlinedColor: SeniorColors.primaryColor500,
    ),
  ),
  dangerIconButtonTheme: SeniorIconButtonThemeData(
    style: SeniorIconButtonStyle(
      borderColor: Colors.transparent,
      buttonColor: SeniorColors.manchesterColorRed,
      disabledBorderColor: Colors.transparent,
      disabledButtonColor: SeniorColors.manchesterColorRed300,
      disabledIconColor: SeniorColors.pureWhite,
      iconColor: SeniorColors.pureWhite,
      outlinedColor: SeniorColors.manchesterColorRed600,
    ),
  ),

  // Info card
  infoCardTheme: const SeniorInfoCardThemeData(
    style: SeniorInfoCardStyle(
      color: SeniorColors.neutralColor100,
      infoColor: SeniorColors.neutralColor800,
      labelColor: SeniorColors.neutralColor600,
    ),
  ),

  // List
  listTheme: const SeniorListThemeData(
    style: SeniorListStyle(
      emphasisTitleColor: SeniorColors.primaryColor500,
      emphasisRightLabelColor: SeniorColors.primaryColor500,
      lineColor: SeniorColors.secondaryColor200,
      neutralTitleColor: SeniorColors.neutralColor800,
      neutralRightLabelColor: SeniorColors.neutralColor600,
      rightIconColor: SeniorColors.neutralColor800,
      subtitleColor: SeniorColors.neutralColor500,
    ),
  ),

  // Loading
  loadingTheme: const SeniorLoadingThemeData(
    style: SeniorLoadingStyle(
      color: SeniorColors.primaryColor500,
    ),
  ),

  // Message card
  messageCardTheme: const SeniorMessageCardThemeData(
    style: SeniorMessageCardStyle(
      color: SeniorColors.secondaryColor100,
      textColor: SeniorColors.pureBlack,
      feedbackItemsColor: SeniorColors.neutralColor600,
    ),
  ),

  // Menu list item
  menuListItemTheme: const SeniorMenuListItemThemeData(
    style: SeniorMenuListItemStyle(
      disabledPushIconColor: SeniorColors.neutralColor900,
      iconColor: SeniorColors.primaryColor500,
      pushIconColor: SeniorColors.primaryColor500,
      subtitleColor: SeniorColors.neutralColor500,
      titleColor: SeniorColors.primaryColor900,
    ),
  ),

  // Modal
  modalTheme: const SeniorModalThemeData(
    style: SeniorModalStyle(
      backgroundColor: SeniorColors.pureWhite,
      contentColor: SeniorColors.secondaryColor700,
      titleColor: SeniorColors.neutralColor800,
    ),
  ),

  // Notification list
  notificationListTheme: const SeniorNotificationListThemeData(
    style: SeniorNotificationListStyle(
      titleColor: SeniorColors.neutralColor800,
      notificationBodyColor: SeniorColors.neutralColor800,
      notificationFooterColor: SeniorColors.neutralColor500,
      notificationTitleColor: SeniorColors.pureBlack,
      separatorColor: SeniorColors.neutralColor300,
    ),
  ),

  // Profile picture
  profilePictureTheme: SeniorProfilePictureThemeData(
    style: SeniorProfilePictureStyle(
      backgroundColor: SeniorColors.secondaryColor400,
      loadingOverlappingdColor: SeniorColors.pureWhite.withOpacity(.5),
      textColor: SeniorColors.pureBlack,
    ),
  ),

  progressBarTheme: const SeniorProgressBarThemeData(
    style: const SeniorProgressBarStyle(
      backgroundColor: SeniorColors.neutralColor400,
      color: SeniorColors.primaryColor400,
    ),
  ),

  // Quotes
  quotesTheme: const SeniorQuotesThemeData(
    style: SeniorQuotesStyle(
      backgroundColor: SeniorColors.secondaryColor100,
      textColor: SeniorColors.neutralColor800,
    ),
  ),

  // Radio button
  radioButtonTheme: const SeniorRadioButtonThemeData(
    style: SeniorRadioButtonStyle(
      disabledFillColor: SeniorColors.secondaryColor300,
      disabledTitleColor: SeniorColors.secondaryColor300,
      fillColor: SeniorColors.primaryColor,
      titleColor: SeniorColors.neutralColor900,
    ),
  ),

  // Rating
  ratingTheme: const SeniorRatingThemeData(
    style: SeniorRatingStyle(
      iconColor: SeniorColors.manchesterColorYellow,
      disabledIconColor: SeniorColors.secondaryColor600,
    ),
  ),

  // Signature
  signatureTheme: SeniorSignatureThemeData(
    style: SeniorSignatureStyle(
      backgroundColor: SeniorColors.pureWhite,
      clearButtonIconColor: SeniorColors.manchesterColorRed,
      disabledClearButtonIconColor: SeniorColors.manchesterColorRed200,
      disabledSaveButtonIconColor: SeniorColors.primaryColor100,
      emptySignatureTextColor: SeniorColors.secondaryColor,
      saveButtonIconColor: SeniorColors.primaryColor,
      signatureBackgrounColor: SeniorColors.pureWhite,
      signatureDottedBorderColor: SeniorColors.secondaryColor500,
    ),
  ),

  // Snackbar
  successSnackbarTheme: const SeniorSnackbarThemeData(
    style: const SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorGreen100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorGreen,
    ),
  ),
  messageSnackbarTheme: const SeniorSnackbarThemeData(
    style: const SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorBlue100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorBlue,
    ),
  ),
  warningSnackbarTheme: const SeniorSnackbarThemeData(
    style: const SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorYellow100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorYellow,
    ),
  ),
  errorSnackbarTheme: const SeniorSnackbarThemeData(
    style: const SeniorSnackbarStyle(
      backgroundColor: SeniorColors.manchesterColorRed100,
      fontColor: SeniorColors.pureBlack,
      iconColor: SeniorColors.manchesterColorRed,
    ),
  ),

  // Square buttons menu
  emphasisSquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundGradientColors: SeniorColors.primaryGradientColors,
      borderColor: Colors.transparent,
      fontColor: SeniorColors.pureWhite,
      iconColor: SeniorColors.pureWhite,
      disabledBackgroundColor: SeniorColors.primaryColor.withOpacity(0.5),
      disabledBorderColor: Colors.transparent,
      disabledFontColor: SeniorColors.pureWhite,
      disabledIconColor: SeniorColors.pureWhite,
    ),
  ),

  emphasisNegativeSquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundColor: SeniorColors.neutralColor100,
      borderColor: SeniorColors.primaryColor,
      fontColor: SeniorColors.secondaryColor,
      iconColor: SeniorColors.primaryColor,
      disabledBackgroundColor: SeniorColors.neutralColor100.withOpacity(0.5),
      disabledBorderColor: SeniorColors.primaryColor.withOpacity(0.5),
      disabledFontColor: SeniorColors.secondaryColor,
      disabledIconColor: SeniorColors.primaryColor,
    ),
  ),

  neutralSquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundColor: SeniorColors.secondaryColor,
      borderColor: Colors.transparent,
      fontColor: SeniorColors.pureWhite,
      iconColor: SeniorColors.pureWhite,
      disabledBackgroundColor: SeniorColors.secondaryColor.withOpacity(0.5),
      disabledBorderColor: Colors.transparent,
      disabledFontColor: SeniorColors.pureWhite,
      disabledIconColor: SeniorColors.pureWhite,
    ),
  ),

  neutralNegativeSquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundColor: SeniorColors.neutralColor100,
      borderColor: SeniorColors.secondaryColor,
      fontColor: SeniorColors.secondaryColor,
      iconColor: SeniorColors.secondaryColor,
      disabledBackgroundColor: SeniorColors.neutralColor100.withOpacity(0.5),
      disabledBorderColor: SeniorColors.secondaryColor.withOpacity(0.5),
      disabledFontColor: SeniorColors.secondaryColor,
      disabledIconColor: SeniorColors.secondaryColor,
    ),
  ),

  ghostSquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundColor: Colors.transparent,
      borderColor: SeniorColors.secondaryColor,
      fontColor: SeniorColors.secondaryColor,
      iconColor: SeniorColors.secondaryColor,
      disabledBackgroundColor: Colors.transparent,
      disabledBorderColor: SeniorColors.secondaryColor.withOpacity(0.5),
      disabledFontColor: SeniorColors.secondaryColor,
      disabledIconColor: SeniorColors.secondaryColor,
    ),
  ),

  ghostNegativeSquareButtonsMenuTheme: SeniorSquareButtonsMenuThemeData(
    style: SeniorSquareButtonsMenuStyle(
      backgroundColor: SeniorColors.neutralColor100,
      borderColor: SeniorColors.secondaryColor,
      fontColor: SeniorColors.secondaryColor,
      iconColor: SeniorColors.secondaryColor,
      disabledBackgroundColor: SeniorColors.neutralColor100.withOpacity(0.5),
      disabledBorderColor: SeniorColors.secondaryColor.withOpacity(0.5),
      disabledFontColor: SeniorColors.secondaryColor,
      disabledIconColor: SeniorColors.secondaryColor,
    ),
  ),

  // Switch
  switchTheme: const SeniorSwitchThemeData(
    style: const SeniorSwitchStyle(
      activeColor: SeniorColors.primaryColor,
      disabledTextColor: SeniorColors.secondaryColor300,
      textColor: SeniorColors.neutralColor900,
      trackColor: SeniorColors.secondaryColor600,
    ),
  ),

  // Tab bar
  tabBarTheme: const SeniorTabBarThemeData(
    style: const SeniorTabBarStyle(
      indicatorColor: SeniorColors.primaryColor,
      labelColor: SeniorColors.neutralColor800,
      unselectedLabelColor: SeniorColors.neutralColor500,
    ),
  ),

  // Text field
  textFieldTheme: const SeniorTextFieldThemeData(
    style: const SeniorTextFieldStyle(
      counterColor: SeniorColors.neutralColor700,
      errorColor: SeniorColors.manchesterColorRed,
      fillColor: SeniorColors.neutralColor100,
      focusedBorderColor: SeniorColors.primaryColor,
      focusedLabelColor: SeniorColors.primaryColor500,
      helperColor: SeniorColors.neutralColor700,
      hintColor: SeniorColors.neutralColor600,
      iconColor: SeniorColors.neutralColor900,
      textColor: SeniorColors.neutralColor900,
      unfocusedBorderColor: SeniorColors.neutralColor400,
      unfocusedLabelColor: SeniorColors.neutralColor900,
    ),
  ),

  timelineTheme: const SeniorTimelineThemeData(
    gutterSpacing: SeniorSpacing.small,
    indicatorSize: 32.0,
    itemGap: SeniorSpacing.xbig,
    lineGap: SeniorSpacing.xsmall,
    strokeWidth: 2.0,
    style: const SeniorTimelineStyle(
      expandIconColor: SeniorColors.neutralColor800,
      expandIconSize: SeniorTypographyIconSize.text,
    ),
  ),

  calendarTheme: SeniorCalendarThemeData(
    style: SeniorCalendarStyle(
      daysButtonColor: Colors.transparent,
      daysColor: SeniorColors.neutralColor900,
      defaultDayTextColor: SeniorColors.secondaryColor500,
      defaultPrevDaysMonthTextStyle: SeniorColors.secondaryColor500,
      headerTextColor: SeniorColors.pureBlack,
      inactiveDaysColor: SeniorColors.secondaryColor500,
      inactiveWeekendColor: SeniorColors.secondaryColor500,
      nextDaysMonthColor: SeniorColors.secondaryColor500,
      nextMonthDayBorderColor: Colors.transparent,
      prevDaysMonthColor: SeniorColors.secondaryColor500,
      prevDaysTextColor: SeniorColors.secondaryColor500,
      prevMonthDayBorderColor: Colors.transparent,
      selectedDayBorderColor: SeniorColors.primaryColor600,
      selectedDayButtonColor: SeniorColors.primaryColor500,
      selectedDayColor: SeniorColors.neutralColor700,
      selectedDayTextColor: SeniorColors.pureWhite,
      thisMonthDayBorderColor: Colors.transparent,
      todayBorderColor: Colors.transparent,
      todayButtonColor: SeniorColors.primaryColor100,
      todayColor: SeniorColors.neutralColor900,
      todayTextColor: SeniorColors.neutralColor900,
      weekdayBackgroundColor: SeniorColors.pureWhite,
      weekdayTextColor: SeniorColors.secondaryColor600,
      weekdaysColor: SeniorColors.secondaryColor500,
      weekendColor: SeniorColors.secondaryColor500,
      yesterdayColor: SeniorColors.secondaryColor500,
    ),
  ),

  themeData: ThemeData(
    primaryColor: SeniorColors.primaryColor,
  ),
);
